@@ -32,7 +32,8 @@ setGeneric("getReferenceCoordinates",
 setMethod("getReferenceCoordinates", 
 		signature(object = "workbook"), 
 		function(object, name) {
-			res <- xlcCall(object, "getReferenceCoordinates", name)
-                        if(is.numeric(res)) { matrix(res, nrow=2, byrow=TRUE)+1 } else { res } 
+      .Deprecated("getReferenceCoordinatesForName")
+			res <- xlcCall(object, "getReferenceCoordinatesForName", name)
+      if(is.numeric(res)) { matrix(res, nrow = 2, byrow = TRUE) + 1 } else { res } 
 		}
 )
